import unittest
from zope.testing import doctest

def test_imports():
    '''
    This tests that old imports still work as the main purpose of this
    package now is to provide backward-compatibility.
    
    >>> from zc.copy import clone, copy, CopyPersistent
    >>> from zc.copy import location_copyfactory, ObjectCopier
    
    >>> from zc.copy.interfaces import ICopyHook, ResumeCopy
    
    No ImportErrors should be raised.
    '''

def test_suite():
    return unittest.TestSuite((
        doctest.DocTestSuite(),
        ))



from setuptools import setup, find_packages

setup(
    name="zc.copy",
    version="1.2",
    install_requires=[
        'setuptools',
        'zope.copy',
        'zope.copypastemove>=3.5.1',
        'zope.location>=3.5.3',
        ],
    packages=find_packages('src'),
    include_package_data=True,
    package_dir= {'':'src'},
    
    namespace_packages=['zc'],

    zip_safe=False,
    author='Zope Project',
    author_email='zope-dev@zope.org',
    description='Pluggable object copying (deprecated in favor of zope.copy)',
    long_description=open("README.txt").read(),
    license='ZPL 2.1',
    keywords="zope zope3 copy clone",
    )
